use utils::{error::{Error, Result}, is_human};

use actix_web::{get, http::header, App, HttpRequest, HttpResponse, HttpServer, Responder};

pub const TATOEBA_API: &str = "https://tatoeba.org/en/api_v0/search";

#[get("/")]
async fn root(request: HttpRequest) -> Result<impl Responder> {
    let target = format!("{TATOEBA_API}?{}", request.query_string());
    if !is_human(&request) {
        return Err(Error::NotHuman { target });
    }
    let resp = reqwest::get(target).await?;
    Ok(HttpResponse::Ok()
        .append_header(header::ContentType(mime::APPLICATION_JSON))
        .body(resp.text().await?))
}

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    HttpServer::new(|| App::new().service(root))
        .bind(("127.0.0.1", 3001))?
        .run()
        .await
}
